<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Circle2TP</name>
    <message>
        <location filename="../Circle2TP.js" line="+76"/>
        <source>First line, arc or circle</source>
        <translation>Pierwsza linia, łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second line, arc or circle</source>
        <translation>Druga linia, łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on circle line</source>
        <translation>Punkt na okręgu</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>Proszę wskazać rozwiązanie</translation>
    </message>
    <message>
        <location line="+139"/>
        <location line="+45"/>
        <source>No solution</source>
        <translation>Brak rozwiązania</translation>
    </message>
    <message>
        <location filename="../Circle2TPInit.js" line="+2"/>
        <source>2 Tan&amp;gents and Point</source>
        <translation>2 stycz&amp;ne i punkt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to two entities, through point</source>
        <translation>Rysuje okrąg styczny do dwóch elementów, przez punkt</translation>
    </message>
</context>
</TS>
